View Source KantanCluster (kantan_cluster v0.5.0)
KantanCluster
かんたんクラスター
Summary
Functions
Starts a node. Configuration options can be specified as a keyword argument
Types
@type message() :: any()
Options for a cluster.
:name- the fully-qualified name of a node that you want to start
- examples:
:"node1@172.17.0.8"
:sname- the short name of a node that you want to start
- examples:
:node1:"node1@localhost"
:cookie- Erlang magic cookie to form a cluster
- default: random cookie
:topologies- the topologies for
Cluster.Supervisor - For available clustering strategies, see https://hexdocs.pm/libcluster/readme.html#clustering.
- the topologies for
@type topic() :: binary()
Functions
@spec node_name() :: node_name()
@spec start_node([option()]) :: :ok
Starts a node. Configuration options can be specified as a keyword argument
KantanCluster.start(
name: :"hoge@172.17.0.7",
cookie: :mycookie
)or in your config/config.exs.
config :kantan_cluster,
name: :"hoge@172.17.0.7",
cookie: :mycookie
@spec unsubscribe(topic()) :: :ok